==> classpath-0.15.tar.gz: classpath-0.15/vm/reference/java/io/VMObjectInputStream.java <==
/* ObjectInputStream.java -- Class used to read serialized objects
   Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2005
   Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package java.io;

import gnu.classpath.VMStackWalker;
import java.lang.reflect.Constructor;
import java.security.AccessController;
import java.security.PrivilegedAction;

final class VMObjectInputStream
{
  private static Class oisClass = ObjectInputStream.class;
  private static Class vmoisClass = VMObjectInputStream.class;

  // PrivilegedAction needed for Class.getClassLoader()
  private static PrivilegedAction loaderAction = new PrivilegedAction()
    {
      public Object run()
      {
	Class[] ctx = VMStackWalker.getClassContext();
	for (int i = 0; i < ctx.length; i++)
	  {
	    ClassLoader cl = ctx[i].getClassLoader();
	    if (cl != null)
	      return cl;
	  }
	return null;
      }
    };

  /**
   * Returns the first user defined class loader on the call stack, or
   * null when no non-null class loader was found.
   */
  static ClassLoader currentClassLoader()
  {
    return (ClassLoader) AccessController.doPrivileged(loaderAction);
  }

  /**
   * Allocates a new Object of type clazz but without running the
   * default constructor on it. It then calls the given constructor on
   * it. The given constructor method comes from the constr_clazz
   * which is a super class of the given clazz.
   */
  static native Object allocateObject(Class clazz, Class constr_clazz,
				      Constructor constructor)
    throws InstantiationException;
}

==> classpath-0.17.tar.gz: classpath-0.17/vm/reference/java/io/VMObjectInputStream.java <==
/* ObjectInputStream.java -- Class used to read serialized objects
   Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2005
   Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package java.io;

import gnu.classpath.VMStackWalker;
import java.lang.reflect.Constructor;
import java.security.AccessController;
import java.security.PrivilegedAction;

final class VMObjectInputStream
{
  private static Class oisClass = ObjectInputStream.class;
  private static Class vmoisClass = VMObjectInputStream.class;

  // PrivilegedAction needed for Class.getClassLoader()
  private static PrivilegedAction loaderAction = new PrivilegedAction()
    {
      public Object run()
      {
	Class[] ctx = VMStackWalker.getClassContext();
	for (int i = 0; i < ctx.length; i++)
	  {
	    ClassLoader cl = ctx[i].getClassLoader();
	    if (cl != null)
	      return cl;
	  }
	return null;
      }
    };

  /**
   * Returns the first user defined class loader on the call stack, or
   * null when no non-null class loader was found.
   */
  static ClassLoader currentClassLoader()
  {
    return (ClassLoader) AccessController.doPrivileged(loaderAction);
  }

  /**
   * Allocates a new Object of type clazz but without running the
   * default constructor on it. It then calls the given constructor on
   * it. The given constructor method comes from the constr_clazz
   * which is a super class of the given clazz.
   */
  static native Object allocateObject(Class clazz, Class constr_clazz,
				      Constructor constructor)
    throws InstantiationException;
}
